@@ -1,4 +1,4 @@
-; <?php exit(); // DO NOT DELETE ?>
+; <?php exit; // DO NOT DELETE?>
 ; DO NOT DELETE THE ABOVE LINE!!!
 ; Doing so will expose this configuration file through your web site!
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -7,8 +7,8 @@
 ;
 ; config.TEMPLATE.inc.php
 ;
-; Copyright (c) 2014-2024 Simon Fraser University
-; Copyright (c) 2003-2024 John Willinsky
+; Copyright (c) 2014-2021 Simon Fraser University
+; Copyright (c) 2003-2021 John Willinsky
 ; Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 ;
 ; OMP Configuration settings.
@@ -29,7 +29,11 @@
 installed = Off
 
 ; The canonical URL to the OMP installation (excluding the trailing slash)
-base_url = "http://pkp.sfu.ca/omp"
+base_url = "https://pkp.sfu.ca/omp"
+
+; Enable strict mode. This will more aggressively cause errors/warnings when
+; deprecated behaviour exists in the codebase.
+strict = Off
 
 ; Session cookie name
 session_cookie_name = OMPSID
@@ -58,24 +62,18 @@ scheduled_tasks = Off
 scheduled_tasks_report_error_only = On
 
 ; Site time zone
-; Please refer to lib/pkp/registry/timeZones.xml for a full list of supported
+; Please refer to https://www.php.net/timezones for a full list of supported
 ; time zones.
-; I.e.:
-; <entry key="Europe/Amsterdam" name="Amsterdam" />
-; time_zone="Amsterdam"
+; I.e.: "Europe/Amsterdam"
+; time_zone="Europe/Amsterdam"
 time_zone = "UTC"
 
 ; Short and long date formats
-date_format_short = "%Y-%m-%d"
-date_format_long = "%B %e, %Y"
-datetime_format_short = "%Y-%m-%d %I:%M %p"
-datetime_format_long = "%B %e, %Y - %I:%M %p"
-time_format = "%I:%M %p"
-
-; Use URL parameters instead of CGI PATH_INFO. This is useful for broken server
-; setups that don't support the PATH_INFO environment variable.
-; WARNING: This option is DEPRECATED and will be removed in the future.
-disable_path_info = Off
+date_format_short = "Y-m-d"
+date_format_long = "F j, Y"
+datetime_format_short = "Y-m-d h:i A"
+datetime_format_long = "F j, Y - h:i A"
+time_format = "h:i A"
 
 ; Use fopen(...) for URL-based reads. Modern versions of dspace
 ; will not accept requests using fopen, as it does not provide a
@@ -85,16 +83,17 @@ allow_url_fopen = Off
 
 ; Base URL override settings: Entries like the following examples can
 ; be used to override the base URLs used by OMP. If you want to use a
-; proxy to rewrite URLs to OMP, configure your proxy's URL here.
-; Syntax: base_url[press_path] = http://www.myUrl.com
-; To override URLs that aren't part of a particular press, use a
-; press_path of "index".
-; Examples:
-; base_url[index] = http://www.myUrl.com
-; base_url[myPress] = http://www.myUrl.com/myPress
-; base_url[myOtherPress] = http://myOtherPress.myUrl.com
+; proxy to rewrite URLs to OMP, configure your proxy's URL with this format.
+; Syntax: base_url[press_path] = http://www.example.com
+;
+; Example1: URLs that aren't part of a particular press.
+;    Example1: base_url[index] = http://www.example.com
+; Example2: URLs that map to a subdirectory.
+;    Example2: base_url[myPress] = http://www.example.com/myPress
+; Example3: URLs that map to a subdomain.
+;    Example3: base_url[myOtherPress] = http://myOtherPress.example.com
 
-; Generate RESTful URLs using mod_rewrite. This requires the
+; Generate RESTful URLs using mod_rewrite.  This requires the
 ; rewrite directive to be enabled in your .htaccess or httpd.conf.
 ; See FAQ for more details.
 restful_urls = Off
@@ -103,31 +102,32 @@ restful_urls = Off
 ; See docs/README.md for more details. The list should be JSON-formatted.
 ; An empty string indicates that all hosts should be trusted (not recommended!)
 ; Example:
-; allowed_hosts = '["mypress.tld", "anotherpress.tld", "mylibrary.tld"]'
+; allowed_hosts = '["myjournal.tld", "anotherjournal.tld", "mylibrary.tld"]'
 allowed_hosts = ''
 
 ; Allow the X_FORWARDED_FOR header to override the REMOTE_ADDR as the source IP
-; Set this to "On" if you are behind a reverse proxy and you control the
-; X_FORWARDED_FOR header.
+; Set this to "On" if you are behind a reverse proxy and you control the X_FORWARDED_FOR
 ; Warning: This defaults to "On" if unset for backwards compatibility.
 trust_x_forwarded_for = Off
 
-; Display a message on the site admin and press manager user home pages if there is an upgrade available
-show_upgrade_warning = On
-
-; Set the following parameter to off if you want to work with the uncompiled (non-minified) JavaScript
-; source for debugging or if you are working off a development branch without compiled JavaScript.
+; Set the following parameter to off if you want to work with the uncompiled
+; (non-minified) JavaScript source for debugging or if you are working off a
+; development branch without compiled JavaScript.
 enable_minified = On
 
 ; Provide a unique site ID and OAI base URL to PKP for statistics and security
 ; alert purposes only.
 enable_beacon = On
 
-; Set this to "On" if you would like to only have a single, site-wide Privacy
-; Statement, rather than a separate Privacy Statement for each press. Setting
-; this to "Off" will allow you to enter a site-wide Privacy Statement as well
-; as separate Privacy Statements for each press.
-sitewide_privacy_statement = Off
+; The number of days a new user has to validate their account
+; A new user account will be expired and removed if this many days have passed since the user registered
+; their account, and they have not validated their account or logged in. If the user_validation_period is set to
+; 0, unvalidated accounts will never be removed. Use this setting to automatically remove bot registrations.
+user_validation_period = 28
+
+; Turn sandbox mode to On in order to prevent the software from interacting with outside systems.
+; Use this for development or testing purposes.
+sandbox = Off
 
 
 ;;;;;;;;;;;;;;;;;;;;;
@@ -163,6 +163,7 @@ debug = Off
 ; - file: Use file-based caching; configured below
 ; - none: Use no caching. This may be extremely slow.
 ; This setting affects locale data, press settings, and plugin settings.
+
 cache = file
 
 ; Enable memcache support
@@ -194,10 +195,7 @@ web_cache_hours = 1
 [i18n]
 
 ; Default locale
-locale = en_US
-
-; Client output/input character set
-client_charset = utf-8
+locale = en
 
 ; Database connection character set
 connection_charset = utf8
@@ -230,6 +228,10 @@ public_user_dir_size = 5000
 ; Permissions mask for created files and directories
 umask = 0022
 
+; The minimum percentage similarity between filenames that should be considered
+; a possible revision
+filename_revision_match = 70
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ; Fileinfo (MIME) Settings ;
@@ -253,9 +255,8 @@ force_ssl = Off
 force_login_ssl = Off
 
 ; This check will invalidate a session if the user's IP address changes.
-; Enabling this option provides some additional security, but may cause
-; login problems for some users (e.g. if a user IP is changed frequently
-; by a server or network configuration).
+; Enabling this option provides some amount of additional security, but may
+; cause problems for users behind a proxy farm (e.g., AOL).
 session_check_ip = Off
 
 ; The encryption (hashing) algorithm to use for encrypting user passwords
@@ -279,9 +280,11 @@ reset_seconds = 7200
 ; stripped.
 allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,dd,b,i,u,img[src|alt],sup,sub,br,p"
 
-;Is implicit authentication enabled or not
-;implicit_auth = On
+; Allowed HTML tags for submission titles only
+; Unspecified attributes will be stripped.
+allowed_title_html = "b,i,u,sup,sub"
 
+;N.b.: The implicit_auth parameter has been removed in favor of plugin implementations such as shibboleth
 
 ;;;;;;;;;;;;;;;;;;
 ; Email Settings ;
@@ -289,6 +292,13 @@ allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,d
 
 [email]
 
+; Default method to send emails
+; Available options: sendmail, smtp, log, phpmailer
+default = sendmail
+
+; Path to the sendmail, -bs argument is for using SMTP protocol
+sendmail_path = "/usr/sbin/sendmail -bs"
+
 ; Use SMTP for sending mail instead of mail()
 ; smtp = On
 
@@ -301,21 +311,9 @@ allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,d
 ; smtp_auth = ssl
 ; smtp_username = username
 ; smtp_password = password
-;
-; Supported smtp_authtype: RAM-MD5, LOGIN, PLAIN, XOAUTH2 (see PHPMailer AuthType)
-; (Leave blank to try them in that order)
-; smtp_authtype =
 
-; The following are required for smtp_authtype = XOAUTH2 (e.g. GMail OAuth)
-; (See https://github.com/PHPMailer/PHPMailer/wiki/Using-Gmail-with-XOAUTH2)
-; smtp_oauth_provider = Google
-; smtp_oauth_email =
-; smtp_oauth_clientid =
-; smtp_oauth_clientsecret =
-; smtp_oauth_refreshtoken =
-
-; Enable suppressing verification of SMTP certificate in PHPMailer
-; Note: this is not recommended per PHPMailer documentation
+; Enable suppressing SSL/TLS peer verification by SMTP transports
+; Note: this is not recommended for security reasons
 ; smtp_suppress_cert_check = On
 
 ; Allow envelope sender to be specified
@@ -347,18 +345,10 @@ allowed_html = "a[href|target|title],em,strong,cite,code,ul,ol,li[class],dl,dt,d
 ; and '%s' to insert the localized sitename.
 ; dmarc_compliant_from_displayname = '%n via %s'
 
-; Amount of time required between attempts to send non-editorial emails
-; in seconds. This can be used to help prevent email relaying via OMP.
-time_between_emails = 3600
-
-; Maximum number of recipients that can be included in a single email
-; (either as To:, Cc:, or Bcc: addresses) for a non-privileged user
-max_recipients = 10
-
 ; If enabled, email addresses must be validated before login is possible.
 require_validation = Off
 
-; The number of days a user has to validate their account before their access key expires.
+; Maximum number of days before an unvalidated account expires and is deleted
 validation_timeout = 14
 
 
@@ -375,6 +365,9 @@ min_word_length = 3
 ; are fetched and merged to provide results for searches with several keywords.
 results_per_keyword = 500
 
+; The number of hours for which keyword search results are cached.
+result_cache_hours = 1
+
 ; Paths to helper programs for indexing non-text files.
 ; Programs are assumed to output the converted text to stdout, and "%s" is
 ; replaced by the file argument.
@@ -409,9 +402,6 @@ oai = On
 ; Changing this setting may affect existing clients and is not recommended.
 repository_id = omp.pkp.sfu.ca
 
-; Maximum number of records per request to serve via OAI
-oai_max_records = 100
-
 
 ;;;;;;;;;;;;;;;;;;;;;;
 ; Interface Settings ;
@@ -420,7 +410,7 @@ oai_max_records = 100
 [interface]
 
 ; Number of items to display per page; can be overridden on a per-press basis
-items_per_page = 25
+items_per_page = 50
 
 ; Number of page links to display; can be overridden on a per-press basis
 page_links = 10
@@ -436,14 +426,17 @@ page_links = 10
 recaptcha = off
 
 ; Public key for reCaptcha (see http://www.google.com/recaptcha)
-recaptcha_public_key = your_public_key
+; recaptcha_public_key = your_public_key
 
 ; Private key for reCaptcha (see http://www.google.com/recaptcha)
-recaptcha_private_key = your_private_key
+; recaptcha_private_key = your_private_key
 
 ; Whether or not to use Captcha on user registration
 captcha_on_register = on
 
+; Whether or not to use Captcha on user login
+captcha_on_login = on
+
 ; Validate the hostname in the ReCaptcha response
 recaptcha_enforce_hostname = Off
 
@@ -461,11 +454,17 @@ recaptcha_enforce_hostname = Off
 ; tar (used in backup plugin, translation packaging)
 tar = /bin/tar
 
-; On systems that do not have libxsl/xslt libraries installed, or for those who
-; require a specific XSLT processor, you may enter the complete path to the
-; XSLT renderer tool, with any required arguments. Use %xsl to substitute the
-; location of the XSL stylesheet file, and %xml for the location of the XML
-; source file; eg:
+; egrep (used in copyAccessLogFileTool)
+egrep = /bin/egrep
+
+; gzip (used in FileManager)
+gzip = /bin/gzip
+
+; On systems that do not have PHP4's Sablotron/xsl or PHP5's libxsl/xslt
+; libraries installed, or for those who require a specific XSLT processor,
+; you may enter the complete path to the XSLT renderer tool, with any
+; required arguments. Use %xsl to substitute the location of the XSL
+; stylesheet file, and %xml for the location of the XML source file; eg:
 ; /usr/bin/java -jar ~/java/xalan.jar -IN %xml -XSL %xsl %params
 ; See xslt_parameter_option below for information on the %params token.
 xslt_command = ""
@@ -508,3 +507,66 @@ deprecation_warnings = Off
 
 ; Log web service request information for debugging
 log_web_service_info = Off
+
+; declare a cainfo path if a certificate other than PHP's default should be used for curl calls.
+; This setting overrides the 'curl.cainfo' parameter of the php.ini configuration file.
+[curl]
+; cainfo = ""
+
+
+;;;;;;;;;;;;;;;;;;;;;;;
+; Job Queues Settings ;
+;;;;;;;;;;;;;;;;;;;;;;;
+
+[queues]
+
+; Default queue driver
+default_connection = "database"
+
+; Default queue to use when a job is added to the queue
+default_queue = "queue"
+
+; Whether or not to turn on the built-in job runner
+;
+; When enabled, jobs will be processed at the end of each web
+; request to the application.
+;
+; Use of the built-in job runner is highly discouraged for high-volume
+; sites. Instead, a worker daemon or cron job should be configured
+; to process jobs off the application's main thread.
+;
+; See: https://docs.pkp.sfu.ca/admin-guide/en/advanced-jobs
+;
+job_runner = On
+
+; The maximum number of jobs to run in a single request when using
+; the built-in job runner.
+job_runner_max_jobs = 30
+
+; The maximum number of seconds the built-in job runner should spend
+; running jobs in a single request.
+;
+; This should be less than the max_execution_time the server has
+; configured for PHP.
+;
+; Lower this setting if jobs are failing due to timeouts.
+job_runner_max_execution_time = 30
+
+; The maximum consumerable memory that should be spent by the built-in
+; job runner when running jobs.
+;
+; Set as a percentage, such as 80%:
+;
+; job_runner_max_memory = 80
+;
+; Or set as a fixed value in megabytes:
+;
+; job_runner_max_memory = 128M
+;
+; When setting a fixed value in megabytes, this should be less than the
+; memory_limit the server has configured for PHP.
+job_runner_max_memory = 80
+
+; Remove failed jobs from the database after the following number of days.
+; Remove this setting to leave failed jobs in the database.
+delete_failed_jobs_after = 180
